powered by
Displays fixture for the tournament when number of teams is not exactly power of two using the "Bye" method
knock_out_fixture(number_of_teams)
input numeric
Displays fixture for the tournament along with other necessary details such as number of matches, number of rounds, number of byes etc.
# NOT RUN { number_of_teams=4 knock_out_fixture(number_of_teams) # }
Run the code above in your browser using DataLab