Learn R Programming

SportsTour (version 0.1.0)

knock_out_two: Displays fixture for the tournament when number of teams is power of two

Description

Displays fixture for the tournament when number of teams is power of two

Usage

knock_out_two(number_of_teams)

Arguments

number_of_teams

input numeric

Value

text

Displays fixture for the tournament

Examples

Run this code
# NOT RUN {
number_of_teams=4
knock_out_two(number_of_teams)
# }

Run the code above in your browser using DataLab