Learn R Programming

SportsTour (version 0.1.0)

round_robin_fixture: Displays fixture for the tournament for a given number of team using "staircase" or "cyclic" method

Description

Displays fixture for the tournament for a given number of team using "staircase" or "cyclic" method

Usage

round_robin_fixture(number_of_teams,method)

Arguments

number_of_teams

numeric

method

method for setting fixture "staircase" for staircase method and "cyclic" for cyclic method

Value

text

Displays fixture for the tournament

Examples

Run this code
# NOT RUN {
number_of_teams=4
round_robin_fixture(number_of_teams,method="staircase")
# }

Run the code above in your browser using DataLab